Pygame Logos Page — pygame-ce v2.4.0 documentation

##### pygame-ce documentation

Pygame-ce Home || Help Contents || Reference Index

Most useful stuff: Color | display | draw | event | font | image | key | locals | mixer | mouse | Rect | Surface | time | music | pygame

Advanced stuff: cursors | joystick | mask | sprite | transform | BufferProxy | freetype | gfxdraw | midi | PixelArray | pixelcopy | sndarray | surfarray | math

Other: camera | controller | examples | scrap | system | tests | touch | version

## Pygame Logos

These logos are available for use in your own game projects. Please put them up wherever you see fit. The logo was created by TheCorruptor on July 29, 2001 and upscaled by Mega_JC on August 29, 2021.

pygame_logo.svg
pygame_logo.png - 1561 x 438
pygame_lofi.svg
pygame_lofi.png - 1561 x 438
pygame_powered.svg
pygame_powered.png - 1617 x 640
pygame_tiny.png - 214 x 60
pygame_powered_lowres.png - 101 x 40

There is a higher resolution layered photoshop image available here. (1.3 MB)

### Legacy logos

legacy_logos.zip - 50.1 KB

Edit on GitHub